<?php

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Serenity\AuthBundle\Command;

use Serenity\AuthBundle\Enum\ResetPasswordType;
use Serenity\CoreBundle\Shared\Messenger\Messaging\CommandInterface;
use Symfony\Component\Messenger\Attribute\AsMessage;

#[AsMessage('sync')]
class ResetPasswordCommand implements CommandInterface
{
    public function __construct(
        public string $email,
        public ResetPasswordType $resetPasswordType,
    ) {
    }
}
