<?php

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Serenity\AuthBundle\Query;

use Serenity\CoreBundle\Shared\Common\UserInterface;
use Serenity\CoreBundle\Shared\Messenger\Messaging\QueryInterface;

/**
 * @implements QueryInterface<UserInterface|null>
 */
class UserByEmailQuery implements QueryInterface
{
    public function __construct(
        public string $email, public ?string $role = null)
    {
    }
}
